pub fn normalize_attribute_names(
attributes: &mut Annotated<impl AttributesLike>,
)Expand description
Normalizes deprecated attributes according to sentry-conventions.
Attributes with a status of "normalize" will be moved to their replacement name.
If there is already a value present under the replacement name, it will be left alone,
but the deprecated attribute is removed anyway.
Attributes with a status of "backfill" will be copied to their replacement name if the
replacement name is not present. In any case, the original name is left alone.