normalize_dsc

Function normalize_dsc 

pub fn normalize_dsc(
    attributes: &mut Annotated<Attributes>,
    is_segment: &Annotated<bool>,
    dsc: Option<EnrichedDsc<'_>>,
)
Normalizes the dynamic sampling context into Attributes.

If is_segment is set to false, the function will only add select attributes that are necessary on every span - both segment and non-segment - for dynamic sampling to work. More attributes are added when is_segment is set to true.