normalize_user_agent

Function normalize_user_agent 

pub fn normalize_user_agent(
    attributes: &mut Annotated<Attributes>,
    client_info: Option<ClientUserAgentInfo<'_>>,
)
Normalizes the user agent/client information into [Attributes].

Does not modify the attributes if there is already browser information present, to preserve original values.

The client_info should be omitted for cases where the info is unreliable or incorrect, for example when the client is a backend SDK or another Relay.