normalize_web_vital_span_segment

Function normalize_web_vital_span_segment 

pub fn normalize_web_vital_span_segment(span: &mut SpanV2)
Makes sure web vital spans are not identified with segments.

This was ported from the legacy pipeline for behavior parity. At some point in the future, web vital spans will become metrics, and this will become academic.