TrimmingProcessor

Struct TrimmingProcessor 

pub struct TrimmingProcessor { /* private fields */ }
Processor for trimming EAP items (logs, V2 spans).

This primarily differs from the regular TrimmingProcessor in the handling of [Attributes]. This processor handles attributes as follows:

  1. Sort them by combined key and value size, where the key size is just the string length and the value size is given by size::attribute_size.
  2. Trim attributes one by one. Key lengths are counted for the attribute’s size, but keys aren’t trimmed—if a key is too long, the attribute is simply discarded.
  3. If we run out of space, all subsequent attributes are discarded.

This means that large attributes will be trimmed or discarded before small ones.

Implementations

Source

impl TrimmingProcessor

pub fn new(removed_key_byte_budget: usize) -> Self

Creates a new trimming processor.