normalize_client_sample_rate

Function normalize_client_sample_rate 

pub fn normalize_client_sample_rate(attributes: &mut Annotated<Attributes>)
Normalizes the client sample rate attribute to be in the range (0, 1].

This is only relevant for spans as other eap types re not sampled.