pub fn normalize_sentry_description(
attributes: &mut Annotated<Attributes>,
name: &Annotated<String>,
)Expand description
Normalizes a V2 span’s SENTRY__DESCRIPTION attribute.
If the span has no description, this will attempt to synthesize one from its attributes using derive_description_for_v2_span.