pub fn normalize_sentry_description(
attributes: &mut Annotated<Attributes>,
name: &Annotated<String>,
)Expand description
Normalizes a V2 span’s SENTRY__DESCRIPTION attribute.
For now, this tries the following steps, in order:
- backfill from the span’s name if its
SENTRY__ORIGINattribute is"manual" - backfill from the span’s
DB__QUERY__TEXTattribute if it exists - backfill a combination of the span’s
HTTP__REQUEST__METHODandURL__FULLattributes, if they both exists.
In the future, this logic will be partly moved to and extended in sentry-conventions.