pub fn normalize_span_name(span: &mut SpanV2)Expand description
Normalizes a V2 span’s name.
If the span has no name, this will attempt to synthesize one from its attributes using relay_spans::name_for_attributes.
This is only relevant for spans converted from V1. Spans that were sent as V2 should always have a name.