pub struct TrimmingProcessor { /* private fields */ }Expand description
Processor for trimming EAP items (logs, V2 spans).
This primarily differs from the regular TrimmingProcessor
in the handling of [Attributes]. This processor handles attributes as follows:
- Sort them by combined key and value size, where the key size is just the string length
and the value size is given by
size::attribute_size. - Trim attributes one by one. Key lengths are counted for the attribute’s size, but keys aren’t trimmed—if a key is too long, the attribute is simply discarded.
- If we run out of space, all subsequent attributes are discarded.
This means that large attributes will be trimmed or discarded before small ones.
Implementations